@@ -7,10 +7,10 @@
 #include "vaultimportingwizard.h"
 #include "ui_vaultimportingwizard.h"
 
+#include <QList>
 #include <QMap>
 #include <QPushButton>
 #include <QStackedLayout>
-#include <QVector>
 
 #include "dialogdsl.h"
 #include "vault.h"
@@ -96,3 +96,5 @@ VaultImportingWizard::VaultImportingWizard(QWidget *parent)
 VaultImportingWizard::~VaultImportingWizard()
 {
 }
+
+#include "moc_vaultimportingwizard.cpp"
